pub trait AutocommitResultExt<T, E> {
// Required method
fn unwrap_autocommit(self) -> Result<T, E>;
}Required Methods
Sourcefn unwrap_autocommit(self) -> Result<T, E>
fn unwrap_autocommit(self) -> Result<T, E>
Unwraps the “commit failed” error variant. Use this in cases where autocommit is instructed to run indefinitely and commit will thus never fail.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".